FreshchatUser class

Constructors

FreshchatUser(String? externalId, String? restoreId)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmail() → String?
getExternalId() → String?
getFirstName() → String?
getLastName() → String?
getPhone() → String?
getPhoneCountryCode() → String?
getRestoreId() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmail(String email) → FreshchatUser
setFirstName(String firstName) → FreshchatUser
setLastName(String lastName) → FreshchatUser
setPhone(String phoneCountryCode, String phone) → FreshchatUser
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited